# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.1

import winrt.system
from winrt import _winrt_windows_media_core_preview

__all__ = [
    "SoundLevelBroker",
]

SoundLevelBroker = _winrt_windows_media_core_preview.SoundLevelBroker



# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.1

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation
import winrt.windows.media

Self = typing.TypeVar('Self')

class SoundLevelBroker_Static(type):
    def add_sound_level_changed(cls, handler: winrt.windows.foundation.EventHandler[winrt.system.Object], /) -> winrt.windows.foundation.EventRegistrationToken: ...
    def remove_sound_level_changed(cls, token: winrt.windows.foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def sound_level(cls) -> winrt.windows.media.SoundLevel: ...

class SoundLevelBroker(winrt.system.Object, metaclass=SoundLevelBroker_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SoundLevelBroker: ...

